==> opennms-model-20.0.0-20170307.173552-106-sources.jar: org/opennms/netmgt/model/topology/SimpleConnection.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.model.topology;

import java.util.List;

import org.opennms.netmgt.model.BridgeBridgeLink;
import org.opennms.netmgt.model.BridgeMacLink;

public class SimpleConnection {
    final List<BridgeMacLink> m_links;
    final BridgeBridgeLink m_dlink;
    
    public SimpleConnection(List<BridgeMacLink> links, BridgeBridgeLink dlink){
        m_links = links;
        m_dlink = dlink;
    }

    public List<BridgeMacLink> getLinks() {
        return m_links;
    }

    public BridgeBridgeLink getDlink() {
        return m_dlink;
    }

}

==> opennms-model-20.0.0-20170524.001834-193-sources.jar: org/opennms/netmgt/model/topology/SimpleConnection.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.model.topology;

import java.util.Set;

import org.opennms.netmgt.model.BridgeBridgeLink;

public class SimpleConnection {
    final Set<String> m_links;
    final BridgeBridgeLink m_dlink;
    
    public SimpleConnection(Set<String> links, BridgeBridgeLink dlink){
        m_links = links;
        m_dlink = dlink;
    }

    public Set<String> getMacs() {
        return m_links;
    }

    public BridgeBridgeLink getDlink() {
        return m_dlink;
    }

}
